searchData={"items":[{"type":"module","title":"Duckdbex","doc":"DuckDB API module","ref":"Duckdbex.html"},{"type":"function","title":"Duckdbex.appender/2","doc":"Creates the Appender to load bulk data into a DuckDB database.\n\nThis is the recommended way to load bulk data.","ref":"Duckdbex.html#appender/2"},{"type":"function","title":"Examples - Duckdbex.appender/2","doc":"iex> {:ok, db} = Duckdbex.open()\n  iex> {:ok, conn} = Duckdbex.connection(db)\n  iex> {:ok, _res} = Duckdbex.query(conn, \"CREATE TABLE table_1 (data INTEGER);\")\n  iex> {:ok, _appender} = Duckdbex.appender(conn, \"table_1\")","ref":"Duckdbex.html#appender/2-examples"},{"type":"function","title":"Duckdbex.appender/3","doc":"Creates the Appender to load bulk data into a DuckDB database with schema name.\n\nThis is the recommended way to load bulk data.","ref":"Duckdbex.html#appender/3"},{"type":"function","title":"Examples - Duckdbex.appender/3","doc":"iex> {:ok, db} = Duckdbex.open()\n  iex> {:ok, conn} = Duckdbex.connection(db)\n  iex> {:ok, _res} = Duckdbex.query(conn, \"CREATE SCHEMA schema_1\")\n  iex> {:ok, _res} = Duckdbex.query(conn, \"CREATE TABLE schema_1.table_1 (data INTEGER);\")\n  iex> {:ok, _appender} = Duckdbex.appender(conn, \"schema_1\", \"table_1\")","ref":"Duckdbex.html#appender/3-examples"},{"type":"function","title":"Duckdbex.appender_add_row/2","doc":"Append row into a DuckDB database table.\n\nAny values added to the appender are cached prior to being inserted into the database system for performance reasons. That means that, while appending, the rows might not be immediately visible in the system. The cache is automatically flushed when the appender goes out of scope or when Duckdbex.appender_close(appender) is called. The cache can also be manually flushed using the Duckdbex.appender_flush(appender) method. After either flush or close is called, all the data has been written to the database system.","ref":"Duckdbex.html#appender_add_row/2"},{"type":"function","title":"Examples - Duckdbex.appender_add_row/2","doc":"iex> {:ok, db} = Duckdbex.open()\n  iex> {:ok, conn} = Duckdbex.connection(db)\n  iex> {:ok, _res} = Duckdbex.query(conn, \"CREATE TABLE table_1 (data INTEGER);\")\n  iex> {:ok, appender} = Duckdbex.appender(conn, \"table_1\")\n  iex> :ok = Duckdbex.appender_add_row(appender, [1])","ref":"Duckdbex.html#appender_add_row/2-examples"},{"type":"function","title":"Duckdbex.appender_add_rows/2","doc":"Append multiple rows into a DuckDB database table at once.\n\nAny values added to the appender are cached prior to being inserted into the database system for performance reasons. That means that, while appending, the rows might not be immediately visible in the system. The cache is automatically flushed when the appender goes out of scope or when `Duckdbex.appender_close/1` is called. The cache can also be manually flushed using the `Duckdbex.appender_flush/1` method. After either flush or close is called, all the data has been written to the database system.","ref":"Duckdbex.html#appender_add_rows/2"},{"type":"function","title":"Examples - Duckdbex.appender_add_rows/2","doc":"iex> {:ok, db} = Duckdbex.open()\n  iex> {:ok, conn} = Duckdbex.connection(db)\n  iex> {:ok, _res} = Duckdbex.query(conn, \"CREATE TABLE table_1 (the_n1 INTEGER, the_str1 STRING);\")\n  iex> {:ok, appender} = Duckdbex.appender(conn, \"table_1\")\n  iex> :ok = Duckdbex.appender_add_rows(appender, [[1, \"one\"], [2, \"two\"]])","ref":"Duckdbex.html#appender_add_rows/2-examples"},{"type":"function","title":"Duckdbex.appender_close/1","doc":"Flush the changes made by the appender and close it. Also it will release appender resource (see Duckdbex.release(resource))\n\nThe appender cannot be used after this point","ref":"Duckdbex.html#appender_close/1"},{"type":"function","title":"Examples - Duckdbex.appender_close/1","doc":"iex> {:ok, db} = Duckdbex.open()\n  iex> {:ok, conn} = Duckdbex.connection(db)\n  iex> {:ok, _res} = Duckdbex.query(conn, \"CREATE TABLE table_1 (the_n1 INTEGER, the_str1 STRING);\")\n  iex> {:ok, appender} = Duckdbex.appender(conn, \"table_1\")\n  iex> :ok = Duckdbex.appender_add_rows(appender, [[1, \"one\"], [2, \"two\"]])\n  iex> {:ok, res} = Duckdbex.query(conn, \"SELECT * FROM table_1;\")\n  iex> [] = Duckdbex.fetch_all(res)\n  iex> :ok = Duckdbex.appender_close(appender)\n  iex> {:ok, res} = Duckdbex.query(conn, \"SELECT * FROM table_1;\")\n  iex> [[1, \"one\"], [2, \"two\"]] = Duckdbex.fetch_all(res)","ref":"Duckdbex.html#appender_close/1-examples"},{"type":"function","title":"Duckdbex.appender_flush/1","doc":"Commit the changes made by the appender.","ref":"Duckdbex.html#appender_flush/1"},{"type":"function","title":"Examples - Duckdbex.appender_flush/1","doc":"iex> {:ok, db} = Duckdbex.open()\n  iex> {:ok, conn} = Duckdbex.connection(db)\n  iex> {:ok, _res} = Duckdbex.query(conn, \"CREATE TABLE table_1 (the_n1 INTEGER, the_str1 STRING);\")\n  iex> {:ok, appender} = Duckdbex.appender(conn, \"table_1\")\n  iex> :ok = Duckdbex.appender_add_rows(appender, [[1, \"one\"], [2, \"two\"]])\n  iex> {:ok, res} = Duckdbex.query(conn, \"SELECT * FROM table_1;\")\n  iex> [] = Duckdbex.fetch_all(res)\n  iex> :ok = Duckdbex.appender_flush(appender)\n  iex> {:ok, res} = Duckdbex.query(conn, \"SELECT * FROM table_1;\")\n  iex> [[1, \"one\"], [2, \"two\"]] = Duckdbex.fetch_all(res)","ref":"Duckdbex.html#appender_flush/1-examples"},{"type":"function","title":"Duckdbex.begin_transaction/1","doc":"Begin a transaction","ref":"Duckdbex.html#begin_transaction/1"},{"type":"function","title":"Examples - Duckdbex.begin_transaction/1","doc":"iex> {:ok, db} = Duckdbex.open()\n  iex> {:ok, conn} = Duckdbex.connection(db)\n  iex> :ok = Duckdbex.begin_transaction(conn)","ref":"Duckdbex.html#begin_transaction/1-examples"},{"type":"function","title":"Duckdbex.columns/1","doc":"Returns columns names from the query result.","ref":"Duckdbex.html#columns/1"},{"type":"function","title":"Examples - Duckdbex.columns/1","doc":"iex> {:ok, db} = Duckdbex.open()\n  iex> {:ok, conn} = Duckdbex.connection(db)\n  iex> {:ok, res} = Duckdbex.query(conn, \"SELECT 1 as 'my_name';\")\n  iex> [\"my_name\"] = Duckdbex.columns(res)","ref":"Duckdbex.html#columns/1-examples"},{"type":"function","title":"Duckdbex.commit/1","doc":"Commit the transaction","ref":"Duckdbex.html#commit/1"},{"type":"function","title":"Examples - Duckdbex.commit/1","doc":"iex> {:ok, db} = Duckdbex.open()\n  iex> {:ok, conn} = Duckdbex.connection(db)\n  iex> :ok = Duckdbex.begin_transaction(conn)\n  iex> :ok = Duckdbex.commit(conn)","ref":"Duckdbex.html#commit/1-examples"},{"type":"function","title":"Duckdbex.connection/1","doc":"Creates connection object to work with database.\n\nTo work with database the connection object is requiered. Connection object hold a shared reference to database, so it is possible to forget the database reference and hold the connection reference only.","ref":"Duckdbex.html#connection/1"},{"type":"function","title":"Examples - Duckdbex.connection/1","doc":"iex> {:ok, db} = Duckdbex.open()\n  iex> {:ok, _conn} = Duckdbex.connection(db)","ref":"Duckdbex.html#connection/1-examples"},{"type":"function","title":"Duckdbex.execute_statement/1","doc":"Execute the prepared statement","ref":"Duckdbex.html#execute_statement/1"},{"type":"function","title":"Examples - Duckdbex.execute_statement/1","doc":"iex> {:ok, db} = Duckdbex.open()\n  iex> {:ok, conn} = Duckdbex.connection(db)\n  iex> {:ok, stmt} = Duckdbex.prepare_statement(conn, \"SELECT 1;\")\n  iex> {:ok, res} = Duckdbex.execute_statement(stmt)\n  iex> [[1]] = Duckdbex.fetch_all(res)","ref":"Duckdbex.html#execute_statement/1-examples"},{"type":"function","title":"Duckdbex.execute_statement/2","doc":"Execute the prepared statement with the given list of parameters","ref":"Duckdbex.html#execute_statement/2"},{"type":"function","title":"Examples - Duckdbex.execute_statement/2","doc":"iex> {:ok, db} = Duckdbex.open()\n  iex> {:ok, conn} = Duckdbex.connection(db)\n  iex> {:ok, stmt} = Duckdbex.prepare_statement(conn, \"SELECT 1 WHERE $1 = 1;\")\n  iex> {:ok, res} = Duckdbex.execute_statement(stmt, [1])\n  iex> [[1]] = Duckdbex.fetch_all(res)","ref":"Duckdbex.html#execute_statement/2-examples"},{"type":"function","title":"Duckdbex.extension_is_loaded/2","doc":"Returns whether extension is loaded","ref":"Duckdbex.html#extension_is_loaded/2"},{"type":"function","title":"Examples - Duckdbex.extension_is_loaded/2","doc":"iex> {:ok, db} = Duckdbex.open()\n  iex> Duckdbex.extension_is_loaded(db, \"parquet\")\n  iex> false","ref":"Duckdbex.html#extension_is_loaded/2-examples"},{"type":"function","title":"Duckdbex.fetch_all/1","doc":"Fetches all data from the query result.\n\nReturns empty list if there are no result to fetch.","ref":"Duckdbex.html#fetch_all/1"},{"type":"function","title":"Examples - Duckdbex.fetch_all/1","doc":"iex> {:ok, db} = Duckdbex.open()\n  iex> {:ok, conn} = Duckdbex.connection(db)\n  iex> {:ok, res} = Duckdbex.query(conn, \"SELECT 1;\")\n  iex> [[1]] = Duckdbex.fetch_all(res)","ref":"Duckdbex.html#fetch_all/1-examples"},{"type":"function","title":"Duckdbex.fetch_chunk/1","doc":"Fetches a data chunk from the query result.\n\nReturns empty list if there are no more results to fetch.","ref":"Duckdbex.html#fetch_chunk/1"},{"type":"function","title":"Examples - Duckdbex.fetch_chunk/1","doc":"iex> {:ok, db} = Duckdbex.open()\n  iex> {:ok, conn} = Duckdbex.connection(db)\n  iex> {:ok, res} = Duckdbex.query(conn, \"SELECT 1;\")\n  iex> [[1]] = Duckdbex.fetch_chunk(res)","ref":"Duckdbex.html#fetch_chunk/1-examples"},{"type":"function","title":"Duckdbex.has_active_transaction/1","doc":"Checks if there is an active transaction for connection","ref":"Duckdbex.html#has_active_transaction/1"},{"type":"function","title":"Examples - Duckdbex.has_active_transaction/1","doc":"iex> {:ok, db} = Duckdbex.open()\n  iex> {:ok, conn} = Duckdbex.connection(db)\n  iex> {:ok, false} = Duckdbex.has_active_transaction(conn)","ref":"Duckdbex.html#has_active_transaction/1-examples"},{"type":"function","title":"Duckdbex.hugeint_to_integer/1","doc":"Convert a duckdb hugeint record to erlang/elixir integer.","ref":"Duckdbex.html#hugeint_to_integer/1"},{"type":"function","title":"Examples - Duckdbex.hugeint_to_integer/1","doc":"iex> {:ok, db} = Duckdbex.open()\n  iex> {:ok, conn} = Duckdbex.connection(db)\n  iex> {:ok, _res} = Duckdbex.query(conn, \"CREATE TABLE hugeints(value HUGEINT);\")\n  iex> {:ok, _res} = Duckdbex.query(conn, \"INSERT INTO hugeints VALUES (98233720368547758080000::hugeint);\")\n  iex> {:ok, res} = Duckdbex.query(conn, \"SELECT * FROM hugeints;\")\n  iex> [[hugeint = {5325, 4808176044395724800}]] = Duckdbex.fetch_all(res)\n  iex> 98233720368547758080000 = Duckdbex.hugeint_to_integer(hugeint)","ref":"Duckdbex.html#hugeint_to_integer/1-examples"},{"type":"function","title":"Duckdbex.integer_to_hugeint/1","doc":"Convert an erlang/elixir integer to a DuckDB hugeint.\n\nFor more information on DuckDB numeric types, see [DuckDB Numeric Data Types](https://duckdb.org/docs/sql/data_types/numeric) For more information on DuckDB numeric types.","ref":"Duckdbex.html#integer_to_hugeint/1"},{"type":"function","title":"Examples - Duckdbex.integer_to_hugeint/1","doc":"iex> {:ok, db} = Duckdbex.open()\n  iex> {:ok, conn} = Duckdbex.connection(db)\n  iex> {:ok, _res} = Duckdbex.query(conn, \"CREATE TABLE hugeints(value HUGEINT);\")\n  iex> {:ok, _res} = Duckdbex.query(conn, \"INSERT INTO hugeints VALUES (98233720368547758080000::hugeint);\")\n  iex> hugeint = Duckdbex.integer_to_hugeint(98233720368547758080000)\n  iex> {:ok, res} = Duckdbex.query(conn, \"SELECT * FROM hugeints WHERE value = $1\", [hugeint])\n  iex> [[{5325, 4808176044395724800}]] = Duckdbex.fetch_all(res)","ref":"Duckdbex.html#integer_to_hugeint/1-examples"},{"type":"function","title":"Duckdbex.is_auto_commit/1","doc":"Check if transaction autocommit is set for connection","ref":"Duckdbex.html#is_auto_commit/1"},{"type":"function","title":"Examples - Duckdbex.is_auto_commit/1","doc":"iex> {:ok, db} = Duckdbex.open()\n  iex> {:ok, conn} = Duckdbex.connection(db)\n  iex> {:ok, true} = Duckdbex.is_auto_commit(conn)","ref":"Duckdbex.html#is_auto_commit/1-examples"},{"type":"function","title":"Duckdbex.library_version/0","doc":"Returns the version of the linked DuckDB, with a version postfix for dev versions\n\nUsually used for developing C extensions that must return this for a compatibility check.","ref":"Duckdbex.html#library_version/0"},{"type":"function","title":"Examples - Duckdbex.library_version/0","doc":"iex> Duckdbex.library_version()\n  iex> \"v0.7.0\"","ref":"Duckdbex.html#library_version/0-examples"},{"type":"function","title":"Duckdbex.library_version/1","doc":"Returns the version of the DuckDB library, for storage format version","ref":"Duckdbex.html#library_version/1"},{"type":"function","title":"Examples - Duckdbex.library_version/1","doc":"iex> Duckdbex.library_version(39)\n  iex> \"v0.6.0 or v0.6.1\"","ref":"Duckdbex.html#library_version/1-examples"},{"type":"function","title":"Duckdbex.number_of_threads/1","doc":"Returns the count of DuckDB threads\n\nThis is DuckDB own native threads (not a dirty scheduler Erlang threads)","ref":"Duckdbex.html#number_of_threads/1"},{"type":"function","title":"Examples - Duckdbex.number_of_threads/1","doc":"iex> {:ok, db} = Duckdbex.open()\n  iex> Duckdbex.number_of_threads(db)\n  iex> 8","ref":"Duckdbex.html#number_of_threads/1-examples"},{"type":"function","title":"Duckdbex.open/0","doc":"Opens database in the memory.","ref":"Duckdbex.html#open/0"},{"type":"function","title":"Examples - Duckdbex.open/0","doc":"iex> {:ok, _db} = Duckdbex.open()","ref":"Duckdbex.html#open/0-examples"},{"type":"function","title":"Duckdbex.open/1","doc":"If the path to the file is specified, then opens the database in the file.\n\nIf specified file does not exist, a new database file with the given name will be created automatically.\nIf database config is specified, then opens the database in the memory with the custom database config.","ref":"Duckdbex.html#open/1"},{"type":"function","title":"Examples - Duckdbex.open/1","doc":"iex> {:ok, _db} = Duckdbex.open(\"my_database.duckdb\")\n\n  iex> {:ok, _db} = Duckdbex.open(%Duckdbex.Config{access_mode: :automatic})","ref":"Duckdbex.html#open/1-examples"},{"type":"function","title":"Duckdbex.open/2","doc":"Opens database in the specified file.\n\nIf specified file does not exist, a new database file with the given name will be created automatically.","ref":"Duckdbex.html#open/2"},{"type":"function","title":"Examples - Duckdbex.open/2","doc":"iex> {:ok, _db} = Duckdbex.open(\"my_database.duckdb\", %Duckdbex.Config{})","ref":"Duckdbex.html#open/2-examples"},{"type":"function","title":"Duckdbex.platform/0","doc":"Returns the Platform of the linked DuckDB library","ref":"Duckdbex.html#platform/0"},{"type":"function","title":"Examples - Duckdbex.platform/0","doc":"iex> Duckdbex.platform()\n  iex> \"osx_amd64\"","ref":"Duckdbex.html#platform/0-examples"},{"type":"function","title":"Duckdbex.prepare_statement/2","doc":"Prepare the specified query, returning a reference to the prepared statement object","ref":"Duckdbex.html#prepare_statement/2"},{"type":"function","title":"Examples - Duckdbex.prepare_statement/2","doc":"iex> {:ok, db} = Duckdbex.open()\n  iex> {:ok, conn} = Duckdbex.connection(db)\n  iex> {:ok, _stmt} = Duckdbex.prepare_statement(conn, \"SELECT 1 WHERE $1 = 1;\")","ref":"Duckdbex.html#prepare_statement/2-examples"},{"type":"function","title":"Duckdbex.query/2","doc":"Issues a query to the database and returns a result reference.","ref":"Duckdbex.html#query/2"},{"type":"function","title":"Examples - Duckdbex.query/2","doc":"iex> {:ok, db} = Duckdbex.open()\n  iex> {:ok, conn} = Duckdbex.connection(db)\n  iex> {:ok, _res} = Duckdbex.query(conn, \"SELECT 1;\")","ref":"Duckdbex.html#query/2-examples"},{"type":"function","title":"Duckdbex.query/3","doc":"Issues a query to the database with parameters and returns a result reference.","ref":"Duckdbex.html#query/3"},{"type":"function","title":"Examples - Duckdbex.query/3","doc":"iex> {:ok, db} = Duckdbex.open()\n  iex> {:ok, conn} = Duckdbex.connection(db)\n  iex> {:ok, _res} = Duckdbex.query(conn, \"SELECT 1 WHERE $1 = 1;\", [1])","ref":"Duckdbex.html#query/3-examples"},{"type":"function","title":"Duckdbex.release/1","doc":"Release resource (db, connection, stmt, query_result)\n\nWill cause destruction and automatic closing the releasing resource in the calling process on dirty schedulers. The released resource cannot be used after this point.\n\nIf you do not release some resource you have the resource will be automatically released by the Erlang garbage collector (GC) when you lose last ref to the resource, but the GC may run resource releasing in the main schedulers which may affect the performance of your main system perfomance.","ref":"Duckdbex.html#release/1"},{"type":"function","title":"Examples - Duckdbex.release/1","doc":"iex> {:ok, db} = Duckdbex.open(\"my_database.duckdb\", %Duckdbex.Config{})\n  iex> {:ok, conn} = Duckdbex.connection(db)\n  iex> {:ok, res} = Duckdbex.query(conn, \"SELECT 1 WHERE $1 = 1;\", [1])\n  iex> :ok = Duckdbex.release(res)\n  iex> :ok = Duckdbex.release(conn)\n  iex> :ok = Duckdbex.release(db)","ref":"Duckdbex.html#release/1-examples"},{"type":"function","title":"Duckdbex.rollback/1","doc":"Rollback the transaction","ref":"Duckdbex.html#rollback/1"},{"type":"function","title":"Examples - Duckdbex.rollback/1","doc":"iex> {:ok, db} = Duckdbex.open()\n  iex> {:ok, conn} = Duckdbex.connection(db)\n  iex> :ok = Duckdbex.begin_transaction(conn)\n  iex> :ok = Duckdbex.rollback(conn)","ref":"Duckdbex.html#rollback/1-examples"},{"type":"function","title":"Duckdbex.set_auto_commit/2","doc":"Set transaction autocommit for connection","ref":"Duckdbex.html#set_auto_commit/2"},{"type":"function","title":"Examples - Duckdbex.set_auto_commit/2","doc":"iex> {:ok, db} = Duckdbex.open()\n  iex> {:ok, conn} = Duckdbex.connection(db)\n  iex> :ok = Duckdbex.set_auto_commit(conn, true)","ref":"Duckdbex.html#set_auto_commit/2-examples"},{"type":"function","title":"Duckdbex.source_id/0","doc":"Returns the commit hash of the linked DuckDB library","ref":"Duckdbex.html#source_id/0"},{"type":"function","title":"Examples - Duckdbex.source_id/0","doc":"iex> Duckdbex.source_id()\n  iex> \"b00b93f0b1\"","ref":"Duckdbex.html#source_id/0-examples"},{"type":"function","title":"Duckdbex.storage_format_version/0","doc":"Returns the version number of the database storage format","ref":"Duckdbex.html#storage_format_version/0"},{"type":"function","title":"Examples - Duckdbex.storage_format_version/0","doc":"iex> Duckdbex.storage_format_version()\n  iex> 43","ref":"Duckdbex.html#storage_format_version/0-examples"},{"type":"type","title":"Duckdbex.appender/0","doc":"","ref":"Duckdbex.html#t:appender/0"},{"type":"type","title":"Duckdbex.connection/0","doc":"","ref":"Duckdbex.html#t:connection/0"},{"type":"type","title":"Duckdbex.db/0","doc":"","ref":"Duckdbex.html#t:db/0"},{"type":"type","title":"Duckdbex.query_result/0","doc":"","ref":"Duckdbex.html#t:query_result/0"},{"type":"type","title":"Duckdbex.reason/0","doc":"","ref":"Duckdbex.html#t:reason/0"},{"type":"type","title":"Duckdbex.statement/0","doc":"","ref":"Duckdbex.html#t:statement/0"},{"type":"module","title":"Duckdbex.Config","doc":"DuckDB database instance configuration.","ref":"Duckdbex.Config.html"},{"type":"type","title":"Duckdbex.Config.optimizer_type/0","doc":"","ref":"Duckdbex.Config.html#t:optimizer_type/0"},{"type":"type","title":"Duckdbex.Config.t/0","doc":"DuckDB database instance configuration type.\n\n`:access_mode`: Access mode of the database. Maybe `:automatic`, `:read_only` or `:read_write`. Default: `:automatic`.\n\n`:checkpoint_wal_size`: Checkpoint when WAL reaches this size. Default: `nil` (16777216 ~16MB). In bytes.\n\n`:use_direct_io`: Whether or not to use Direct IO, bypassing operating system buffers. Default: `false`.\n\n`:load_extensions`: Whether extensions should be loaded on start-up. Default: `true`.\n\n`:autoload_known_extensions`: Whether known extensions are allowed to be automatically loaded when a query depends on them. Default: `false`.\n\n`:autoinstall_known_extensions`: Whether known extensions are allowed to be automatically installed when a query depends on them. , Default: `false`.\n\n`:custom_extension_repo`: Override for the default extension repository. Default: 'nil'.\n\n`:autoinstall_extension_repo`: Override for the default autoload extension repository. Default: 'nil'.\n\n`:maximum_memory`: The maximum memory used by the database system (in bytes). Default: `nil` (80% of System available memory)\n\n`:maximum_swap_space`: The maximum size of the 'temp_directory' folder when set (in bytes). Default: nil (90% of available disk space).\n\n`:maximum_threads`: The maximum amount of native CPU threads used by the database system. Default: `nil` (all available).\n\n`:external_threads`: The number of external threads that work on DuckDB tasks. Must be smaller or equal to maximum_threads. Default: `1`.\n\n`:use_temporary_directory`: Whether or not to create and use a temporary directory to store intermediates that do not fit in memory. Default: `true`\n\n`:temporary_directory`: Directory to store temporary structures that do not fit in memory. Default: `nil` (current)\n\n`:trim_free_blocks`: Whether or not to invoke filesystem trim on free blocks after checkpoint. This will reclaim space for sparse files, on platforms that support it. Default: `false`\n\n`:buffer_manager_track_eviction_timestamps`: Record timestamps of buffer manager unpin() events. Usable by custom eviction policies. Default `false`.\n\n`:allow_unredacted_secrets`: Whether or not to allow printing unredacted secrets. Default: `false`.\n\n`:collation`: The collation type of the database. Default: `nil`\n\n`:default_order_type`: The order type used when none is specified. Maybe `:asc`, `:desc`. Deafult: `:asc`.\n\n`:default_null_order`: Null ordering used when none is specified. Maybe `:nulls_first`, `:nulls_last`. Default: `:nulls_last`.\n\n`:enable_external_access`: Enable COPY and related commands. Default: `true`.\n\n`:object_cache_enable`: Whether or not object cache is used. Default: `false`.\n\n`:http_metadata_cache_enable`: Whether or not the global http metadata cache is used. Default: `false`.\n\n`:http_proxy`: HTTP Proxy config as 'hostname:port'. Default: `nil`.\n\n`:http_proxy_username`: HTTP Proxy username for basic auth. Default: `nil`.\n\n`:http_proxy_password`: HTTP Proxy password for basic auth. Default: `nil`.\n\n`:force_checkpoint`: Force checkpoint when CHECKPOINT is called or on shutdown, even if no changes have been made. Default: `false`.\n\n`:checkpoint_on_shutdown`: Run a checkpoint on successful shutdown and delete the WAL, to leave only a single database file behind. Default: `true`.\n\n`:serialization_compatibility`: Serialize the metadata on checkpoint with compatibility for a given DuckDB version. Default: `nil` (latest version of DuckDB).\n\n`:disabled_optimizers`: The set(elixir list) of disabled optimizers. Default: `nil`.\n\n`:force_compression`: Force a specific compression method to be used when checkpointing (if available). Maybe `:auto`, `:uncompressed`, `:constant`, `:rle`, `:dictionary`, `:pfor_delta`, `:bitpacking`, `:fsst`, `:chimp`, `:patas`. Default: `:auto`.\n\n`:force_bitpacking_mode`: Force a specific bitpacking mode to be used when using the bitpacking compression method. Maybe `:auto`, `:constant`, `:constant_delta`, `:delta_for`, `:for`. Default: `:auto`.\n\n`:preserve_insertion_order`: Whether or not preserving insertion order should be preserved. Default: `true`.\n\n`:arrow_offset_size`: Whether Arrow Arrays use Large or Regular buffers. Default `:regular`.\n\n`:arrow_use_list_view`: Whether LISTs should produce Arrow ListViews. Default: `false`.\n\n`:arrow_arrow_lossless_conversion`: Whenever a DuckDB type does not have a clear native or canonical extension match in Arrow, export the types with a duckdb.type_name extension name. Default: `false`.\n\n`:produce_arrow_string_views`: Whether when producing arrow objects we produce string_views or regular strings. Default: `false`.\n\n`:extension_directory`: Directory to store extension binaries in. Default: `nil`.\n\n`:allow_unsigned_extensions`: Whether unsigned extensions should be loaded. Default: `false`.\n\n`:allow_community_extensions`: Whether community extensions should be loaded. Default: `true`.\n\n`:allow_extensions_metadata_mismatch`: Whether extensions with missing metadata should be loaded. Default: `false`.\n\n`:enable_fsst_vectors`: Enable emitting FSST Vectors. Default: `false`.\n\n`:enable_view_dependencies`: Enable VIEWs to create dependencies. Default: `false`.\n\n`:enable_macro_dependencies`: Enable macros to create dependencies. Default: `false`.\n\n`:user_options`: Default: The set of user-provided options. `nil`.\n\n`:unrecognized_options`: The set of unrecognized (other) options. Default: `nil`.\n\n`:immediate_transaction_mode`: Start transactions immediately in all attached databases - instead of lazily when a database is referenced. Default: `false`.\n\n`:lock_configuration`: Whether or not the configuration settings can be altered. Default: `false`.\n\n`:allocator_flush_threshold`: The peak allocation threshold at which to flush the allocator after completing a task (1 << 27, ~128MB). In bytes. Default: `nil` (134217728 bytes);\n\n`:allocator_bulk_deallocation_flush_threshold`: If bulk deallocation larger than this occurs, flush outstanding allocations (1 << 30, ~1GB). Default: `nil` (536870912 in bytes)\n\n`:allocator_background_threads`:  Whether the allocator background thread is enabled. Default: `false`.\n\n`:duckdb_api`: DuckDB API surface. Default: `nil`.\n\n`:custom_user_agent`: Metadata from DuckDB callers. Default: `nil`.\n\n`:default_block_alloc_size`: The default block allocation size for new duckdb database files (new as-in, they do not yet exist). In bytes. Default: `nil` (DUCKDB_BLOCK_ALLOC_SIZE = 262144 ULL)\n\n`:abort_on_wal_failure`: Whether or not to abort if a serialization exception is thrown during WAL playback (when reading truncated WAL). Default: `false`.\n\n`:index_scan_percentage`: The index_scan_percentage sets a threshold for index scans. If fewer than MAX(index_scan_max_count, index_scan_percentage * total_row_count) rows match, we perform an index scan instead of a table scan. Default: `nil` (0.001).\n\n`:index_scan_max_count`: The index_scan_max_count sets a threshold for index scans. If fewer than MAX(index_scan_max_count, index_scan_percentage * total_row_count) rows match, we perform an index scan instead of a table scan. Default: `nil` (STANDARD_VECTOR_SIZE = 2048).\n\n`:catalog_error_max_schemas`: The maximum number of schemas we will look through for \"did you mean...\" style errors in the catalog. Default: `nil` (100).\n\n`:max_vacuum_tasks`: The maximum amount of vacuum tasks to schedule during a checkpoint. Default: `nil` (100).\n\n`:memory_allocator`: The memory allocator used by the database system. Maybe `:duckdb` - native DuckDB allocator or `:erlang` - erlang 'void *enif_alloc(size_t size)' allocator. Default: `:duckdb`.","ref":"Duckdbex.Config.html#t:t/0"},{"type":"extras","title":"Duckdbex","doc":"# Duckdbex\n\nThis is **Elixir** Library what embeds C++ [DuckDB](https://duckdb.org) database into you **Elixir** application.\n\nDuckDB is an in-process SQL database management system designed to support analytical query workloads, also known as Online analytical processing (OLAP). It has no external dependencies, neither for compilation nor during run-time and completely embedded (like Sqlite) within a host (BEAM in our case) process.\n\nTo find out where and why you could use DuckDB, please, see [why DuckDB](https://duckdb.org/why_duckdb) section of DuckDB docs.\n\nAlso, you may find useful the DuckDB [documentation](https://duckdb.org/docs/sql/introduction).\n\nThe library uses `amalgamation` of the DuckDB sources, which combine all sources into two files duckdb.hpp and duckdb.cpp. This is the standard source distribution of libduckdb. `Amalgamation` allows to work with [CSV](https://duckdb.org/docs/data/csv) and [Parquet](https://duckdb.org/docs/data/parquet) but it does not yet include DuckDB extensions like [JSON](https://duckdb.org/docs/extensions/json), [Full Text Search](https://duckdb.org/docs/extensions/full_text_search), [HTTPFS](https://duckdb.org/docs/extensions/httpfs), [SQLite Scanner](https://duckdb.org/docs/extensions/sqlite_scanner), [Postgres Scanner](https://duckdb.org/docs/extensions/postgres_scanner) and [Substrait](https://duckdb.org/docs/extensions/substrait).\n\nAll NIF functions implemented as [**Dirty NIF**](https://www.erlang.org/doc/man/erl_nif.html)\n\n**DuckDB is in the active development phase, and new version of library may not open the database created by the old version.**\n\n[HexDocs](https://hexdocs.pm/duckdbex/)","ref":"readme.html"},{"type":"extras","title":"Installation - Duckdbex","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `duckdbex` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:duckdbex, \"~> 0.3.0\"}\n  ]\nend\n```\n\n# Usage\n\nUsing the `duckdbex` is quite simple. You need to open database file, create connection, run a query and fetch the results. [livebook](https://github.com/AlexR2D2/duckdbex/blob/main/duckdbex_sandbox.livemd)","ref":"readme.html#installation"},{"type":"extras","title":"Open database - Duckdbex","doc":"To open the DuckDB database, you must specify the path to the DuckDB file\n\n```elixir\n# Open an existing database file\n{:ok, db} = Duckdbex.open(\"exis_movies.duckdb\")\n```\n\nIf specified database file does not exist, a new database file with the given name will be created automatically.\n\n```elixir\n# If the specified file does not exist the new database will be created\n{:ok, db} = Duckdbex.open(\"not_yet_exist_my_new_duckdb_database\")\n```\n\nIf you do not specify any database file the database will be created in the memory. Note that for an in-memory database no data is persisted to disk (i.e. all data is lost when you exit the app or database|connection object out of scope).\n\n```elixir\n# Just create database in the memory\n{:ok, db} = Duckdbex.open()\n```\n\nThe DuckDB has a number of different options and could be configured by passing the `Duckdbex.Config` struct into the `Duckdbex.open/1` or `Duckdbex.open/2`.\n\n```elixir\n{:ok, _db} = Duckdbex.open(%Duckdbex.Config{checkpoint_wal_size: 8388608})\n```","ref":"readme.html#open-database"},{"type":"extras","title":"Create Connection - Duckdbex","doc":"With the DuckDB instance, you can create one or many Connection instances using the `Duckdbex.connection/1` function. In fact, the DuckDB connection is the native OS thread (not a lightweight Elixir process). While individual connections are thread-safe, they will be locked during querying. So, it is recommended to use the different DuckDB connections in the different Elixir processees to allow for the best parallel performance.\n\n```elixir\n{:ok, db} = Duckdbex.open()\n\n# Create a connection to the opened database\n{:ok, conn} = Duckdbex.connection(db)\n```","ref":"readme.html#create-connection"},{"type":"extras","title":"Make a Query - Duckdbex","doc":"To make a query you need call `Duckdbex.query/2` passing connection reference and query string. Query parameters can be passed as list into `Duckdbex.query/3`. The query call will return the reference to the result.\n\n```elixir\n{:ok, db} = Duckdbex.open()\n{:ok, conn} = Duckdbex.connection(db)\n\n# Run a query and get the reference to the result\n{:ok, result_ref} = Duckdbex.query(conn, \"SELECT 1;\")\n\n# Run a query with parameters\n{:ok, result_ref} = Duckdbex.query(conn, \"SELECT 1 WHERE $1 = 1;\", [1])\n```","ref":"readme.html#make-a-query"},{"type":"extras","title":"Fetch Result - Duckdbex","doc":"To get data from result you need pass result reference from the `Duckdbex.query/2` or `Duckdbex.query/3` call into the `Duckdbex.fetch_all/1` or `Duckdbex.fetch_chunk/1`. The `Duckdbex.fetch_all/1` will return all the data at once. To get data chunk by chunk you should call `Duckdbex.fetch_chunk/1`.\n\n```elixir\n# Run a query and get the reference to the result\n{:ok, result_ref} = Duckdbex.query(conn, \"\"\"\n  SELECT userId, movieId, rating FROM ratings WHERE userId = $1;\n\"\"\", [1])\n\n# Get all the data from the result reference at once\nDuckdbex.fetch_all(result_ref)\n# => [[userId: 1, movieId: 1, rating: 6], [userId: 1, movieId: 2, rating: 12]]\n```\n\nor by chunks\n\n```elixir\n# Run a query and get the reference to the result\n{:ok, result_ref} = Duckdbex.query(conn, \"SELECT * FROM ratings;\")\n\n# fetch chunk\nDuckdbex.fetch_chunk(result_ref)\n# => [[userId: 1, movieId: 1, rating: 6], [userId: 1, movieId: 2, rating: 12]...]\n\n# fetch next chunk\nDuckdbex.fetch_chunk(result_ref)\n# => [ ]\n\n...\n\n# the data is over and fetch_chunk returns the empty list\nDuckdbex.fetch_chunk(result_ref)\n# => []\n```","ref":"readme.html#fetch-result"},{"type":"extras","title":"Prepared statement - Duckdbex","doc":"Prepared statement speeding up queries that will be executed many times with different parameters. Also it allows to avoid string concatenation/SQL injection attacks.\n\n```elixir\n# Prepare statement\n{:ok, stmt_ref} = Duckdbex.prepare_statement(conn, \"SELECT 1;\")\n\n# Execute statement\n{:ok, result_ref} = Duckdbex.execute_statement(stmt_ref)\n\n# Fetch result\nDuckdbex.fetch_all(result_ref)\n# => [[1]]\n```\n\nor with parameters\n\n```elixir\n# Prepare statement\n{:ok, stmt_ref} = Duckdbex.prepare_statement(conn, \"SELECT * FROM ratings WHERE userId = $1;\")\n\n# Execute statement\n{:ok, result_ref} = Duckdbex.execute_statement(stmt_ref, [1])\n# fetch result ...\n\n# Execute statement\n{:ok, result_ref} = Duckdbex.execute_statement(stmt_ref, [42])\n# fetch result ...\n```","ref":"readme.html#prepared-statement"},{"type":"extras","title":"Importing Data - Duckdbex","doc":"DuckDB provides several methods that allows you to easily and efficiently insert data to the database.\n\n* [Insert Statements](#insert-statements)\n* [CSV Files](#csv-files)\n* [Parquet Files](#parquet-files)\n* [Appender](#appender)","ref":"readme.html#importing-data"},{"type":"extras","title":"Insert Statements - Duckdbex","doc":"This is standart way of inserting data into relational database, but DuckDB **is not recommended to use this method if you are inserting more than a few records**. See [details](https://duckdb.org/docs/data/insert). To insert bulk data into database, please, use [Appender](#appender).\n\n```elixir\n{:ok, db} = Duckdbex.open()\n{:ok, conn} = Duckdbex.connection(db)\n{:ok, _res} = Duckdbex.query(conn, \"CREATE TABLE people(id INTEGER, name VARCHAR);\")\n\n{:ok, _res} = Duckdbex.query(conn, \"INSERT INTO people VALUES (1, 'Mark'), (2, 'Hannes');\")\n```\n\nA more detailed description together with syntax diagram can be found [here](https://duckdb.org/docs/sql/statements/insert).","ref":"readme.html#insert-statements"},{"type":"extras","title":"CSV Files - Duckdbex","doc":"DuckDB has an embedded CSV reader that allows to load CSV files directly into database (escaping data transfering from Elixir to NIF, so ERTS doesn't involved in this). Also, DuckDB supports **compressed** CSV files, e.g. a gzipped file like `my_csv_file.csv.gz` and etc.\n\nFor example we have a `test.csv` CSV file:\n```csv\nFlightDate|UniqueCarrier|OriginCityName|DestCityName\n1988-01-01|AA|New York, NY|Los Angeles, CA\n1988-01-02|AA|New York, NY|Los Angeles, CA\n1988-01-03|AA|New York, NY|Los Angeles, CA\n```\n\nLet's load this file into database:\n\n```elixir\n{:ok, db} = Duckdbex.open()\n{:ok, conn} = Duckdbex.connection(db)\n\n# read a CSV file from disk, auto-infer options\n{:ok, res} = Duckdbex.query conn, \"SELECT * FROM 'test.csv';\"\n\nDuckdbex.fetch_all(res)\n# will result in\n[\n  [{1988, 1, 1}, \"AA\", \"New York, NY\", \"Los Angeles, CA\"],\n  [{1988, 1, 2}, \"AA\", \"New York, NY\", \"Los Angeles, CA\"],\n  [{1988, 1, 3}, \"AA\", \"New York, NY\", \"Los Angeles, CA\"]\n]\n```\n\nor we could export data directly into CSV (escaping Elixir)\n\n```elixir\nDuckdbex.query conn, \"CREATE TABLE ontime AS SELECT * FROM 'test.csv';\"\n\n# write the result of a query to a CSV file\nDuckdbex.query conn, \"COPY (SELECT * FROM ontime) TO 'test.csv' WITH (HEADER 1, DELIMITER '|');\"\n```\n\nsee more examples [here](https://duckdb.org/docs/data/csv)","ref":"readme.html#csv-files"},{"type":"extras","title":"Parquet Files - Duckdbex","doc":"[Parquet](https://parquet.apache.org) is an open source, column-oriented data file format designed for efficient data storage and retrieval. It provides efficient data compression and encoding schemes with enhanced performance to handle complex data in bulk. DuckDB has a built-in Parquet reader. Like CSV reader it works directly with the files escaping ERTS.\n\n```elixir\n# download parquet extension (the .so/.dll extension will be downloaded from the remote source)\nDuckdbex.query conn, \"INSTALL 'parquet';\"\n\n# load parquet extension into the app\nDuckdbex.query conn, \"LOAD 'parquet';\"\n\n# read a single parquet file\nDuckdbex.query conn, \"SELECT * FROM 'test.parquet';\"\n\n# figure out which columns/types are in a parquet file\nDuckdbex.query conn, \"DESCRIBE SELECT * FROM 'test.parquet';\"\n\n# read all files that match the glob pattern\nDuckdbex.query conn, \"SELECT * FROM 'test/*.parquet';\"\n\n# export the table contents of the entire database as parquet\nDuckdbex.query conn, \"EXPORT DATABASE 'target_directory' (FORMAT PARQUET);\"\n```\nyou can find more examples [here](https://duckdb.org/docs/data/parquet)","ref":"readme.html#parquet-files"},{"type":"extras","title":"Appender - Duckdbex","doc":"Appender can be used to load bulk data into a DuckDB database.\n\n```elixir\n{:ok, db} = Duckdbex.open()\n{:ok, conn} = Duckdbex.connection(db)\n\nDuckdbex.query(conn, \"CREATE TABLE people(id INTEGER, name VARCHAR);\")\n\n# Create Appender for table 'people'\n{:ok, appender} = Duckdbex.appender conn, \"people\"\n\n# Append two rows at once.\nDuckdbex.appender_add_rows appender, [[2, \"Sarah\"], [3, \"Alex\"]]\n\n# Persist cached rows\nDuckdbex.appender_flush()\n```\n\nAny values added to the appender are cached prior to being inserted into the database system for performance reasons. That means that, while appending, the rows might not be immediately visible in the system. The cache is automatically flushed when the appender goes out of scope or when `Duckdbex.appender_close/1` is called. The cache can also be manually flushed using the `Duckdbex.appender_flush/1` method. After either flush or close is called, all the data has been written to the database system.","ref":"readme.html#appender"},{"type":"extras","title":"Data Types - Duckdbex","doc":"Along with [General-Purpose Data types](https://duckdb.org/docs/sql/data_types/overview) DuckDB supports three nested data types: [LIST](https://duckdb.org/docs/sql/data_types/list), [STRUCT](https://duckdb.org/docs/sql/data_types/struct) and [MAP](https://duckdb.org/docs/sql/data_types/map). There is also [UNION](https://duckdb.org/docs/sql/data_types/union) data type what implemented on top of STRUCT types, and simply keep the “tag” as the first entry. Each supports different use cases and has a different structure.\n\n**You can find more examples about how to work with different types [here](https://github.com/AlexR2D2/duckdbex/test/nif/types_test.exs).**","ref":"readme.html#data-types"},{"type":"extras","title":"LIST - Duckdbex","doc":"An ordered sequence of data values of the same type.\nEach row must have the same data type within each LIST, but can have any number of elements.\n\n```elixir\n# Just select a list\n{:ok, r} = Duckdbex.query(conn, \"SELECT [1, 2, 3];\")\n[[[1, 2, 3]]] = Duckdbex.fetch_all(r)\n\n# Table with columns of LIST type\nDuckdbex.query(conn, \"CREATE TABLE list_table (int_list INT[], varchar_list VARCHAR[]);\")\nDuckdbex.query(conn, \"INSERT INTO list_table VALUES ([1, 2], ['one', 'two']), ([4, 5], ['three', NULL]), ([6, 7], NULL);\")\n{:ok, r} = Duckdbex.query(conn, \"SELECT * FROM list_table\")\n[[[1, 2], [\"one\", \"two\"]], [[4, 5], [\"three\", nil]], [[6, 7], nil]] = Duckdbex.fetch_all(r)\n```","ref":"readme.html#list"},{"type":"extras","title":"STRUCT - Duckdbex","doc":"Conceptually, a STRUCT column contains an ordered list of other columns called “entries”. The entries are referenced by name using strings. This document refers to those entry names as keys. Each row in the STRUCT column must have the same keys. Each key must have the same type of value for each row. See more [here](https://duckdb.org/docs/sql/data_types/struct).\n\n```elixir\n{:ok, r} = Duckdbex.query(conn, \"SELECT {'x': 1, 'y': 2, 'z': 3};\")\n[[%{\"x\" => 1, \"y\" => 2, \"z\" => 3}]] = Duckdbex.fetch_all(r)\n```","ref":"readme.html#struct"},{"type":"extras","title":"MAP - Duckdbex","doc":"MAPs are similar to STRUCTs in that they are an ordered list of “entries” where a key maps to a value. However, MAPs do not need to have the same keys present on each row, and thus open additional use cases. MAPs are useful when the schema is unknown beforehand, and when adding or removing keys in subsequent rows. Their flexibility is a key differentiator.\nSee more [here](https://duckdb.org/docs/sql/data_types/map).\n\n```elixir\nDuckdbex.query(conn, \"CREATE TABLE map_table (map_col MAP(INT, DOUBLE));\")\nDuckdbex.query(conn, \"INSERT INTO map_table VALUES (map([1, 2], [2.98, 3.14])), (map([3, 4], [9.8, 1.6]));\")\n\n{:ok, r} = Duckdbex.query(conn, \"SELECT * FROM map_table\")\n[[[{1, 2.98}, {2, 3.14}]], [[{3, 9.8}, {4, 1.6}]]] = Duckdbex.fetch_all(r)\n```","ref":"readme.html#map"},{"type":"extras","title":"UNION - Duckdbex","doc":"A UNION type (not to be confused with the SQL UNION operator) is a nested type capable of holding one of multiple “alternative” values, much like the union in C. The main difference being that these UNION types are tagged unions and thus always carry a discriminator “tag” which signals which alternative it is currently holding, even if the inner value itself is null. See more [here](https://duckdb.org/docs/sql/data_types/union).\n\n\n```elixir\n{:ok, _} = Duckdbex.query(conn, \"CREATE TABLE tbl1(u UNION(num INT, str VARCHAR));\")\n{:ok, _} = Duckdbex.query(conn, \"INSERT INTO tbl1 values (1) , ('two') , (union_value(str := 'three'));\")\n{:ok, r} = Duckdbex.query(conn, \"SELECT u from tbl1;\")\n[[{\"num\", 1}], [{\"str\", \"two\"}], [{\"str\", \"three\"}]] = Duckdbex.fetch_all(r)\n```","ref":"readme.html#union"},{"type":"extras","title":"ENUM - Duckdbex","doc":"The ENUM type represents a dictionary data structure with all possible unique values of a column. For example, a column storing the days of the week can be an Enum holding all possible days. Enums are particularly interesting for string columns with high cardinality. This is because the column only stores a numerical reference to the string in the Enum dictionary, resulting in immense savings in disk storage and faster query performance. See more [here](https://duckdb.org/docs/sql/data_types/enum).\n\n```elixir\n{:ok, _} = Duckdbex.query(conn, \"CREATE TYPE mood AS ENUM ('sad', 'ok', 'happy');\")\n\n{:ok, _} = Duckdbex.query(conn, \"CREATE TABLE person (name text, current_mood mood);\")\n{:ok, _} = Duckdbex.query(conn, \"INSERT INTO person VALUES ('Pedro','happy'), ('Mark', NULL), ('Pagliacci', 'sad'), ('ackey', 'ok');\")\n\n{:ok, r} = Duckdbex.query(conn, \"SELECT * FROM person WHERE current_mood = 'sad';\")\n[[\"Pagliacci\", \"sad\"]] = Duckdbex.fetch_all(r)\n\n{:ok, r} = Duckdbex.query(conn, \"SELECT * FROM person WHERE current_mood = $1;\", [\"sad\"])\n[[\"Pagliacci\", \"sad\"]] = Duckdbex.fetch_all(r)\n```","ref":"readme.html#enum"},{"type":"extras","title":"Extensions - Duckdbex","doc":"DuckDB allows to load and use extensions. By default extensions are downloaded from the remote source. These extensions are verified and signed. Also you can use you own unsigned extensions.","ref":"readme.html#extensions"},{"type":"extras","title":"Remote installation - Duckdbex","doc":"Download and install verified signed extension from remote source\n\n```elixir\n# download extension binary\n{:ok, _} = Duckdbex.query(conn, \"INSTALL 'parquet';\")\n\n# load extension into the app\n{:ok, _} = Duckdbex.query(conn, \"LOAD 'parquet';\")\n\n# now you can use the extension\n{_, r} = Duckdbex.query(conn, \"SELECT * FROM 'test.parquet';\")\n```","ref":"readme.html#remote-installation"},{"type":"extras","title":"Local installation (unsigned extension) - Duckdbex","doc":"Almost the same as above, but you must configure DuckDB to allow unsigned extension\n\n```elixir\n# configure DuckDB to allow  unsigned extension\nconf = %Duckdbex.Config{allow_unsigned_extensions: true}\n{:ok, db} = Duckdbex.open(conf)\n{:ok, conn} = Duckdbex.open(db)\n\n# install unsigned extension from local source\n{:ok, _} = Duckdbex.query(conn, \"INSTALL '/home/extensions/my_custom.duckdb_extension';\")\n{:ok, _} = Duckdbex.query(conn, \"LOAD '/home/extensions/my_custom.duckdb_extension';\")\n```","ref":"readme.html#local-installation-unsigned-extension"},{"type":"extras","title":"Custom build DuckDB extensions - Duckdbex","doc":"If extension what downloaded from the remote source doesn't load because of mismatch of compiler/syslibs and etc., you can build DuckDB extensions by youself and use it as unsigned extensions. You need cmake installed.\n\n```shell\n$ git clone https://github.com/duckdb/duckdb.git\nduckdb$ cd duckdb\nduckdb$ BUILD_JSON=1 make\nduckdb$ cp build/release/extension/json/json.duckdb_extension /home/duckdb_unsigned_extensions\n```\nNow we can use this extension\n\n```elixir\nconf = %Duckdbex.Config{allow_unsigned_extensions: true}\n{:ok, db} = Duckdbex.open(conf)\n{:ok, conn} = Duckdbex.open(db)\n\n# load extension into the app\n{:ok, _} = Duckdbex.query(conn, \"INSTALL '/home/duckdb_unsigned_extensions/json.duckdb_extension';\")\n{:ok, _} = Duckdbex.query(conn, \"LOAD '/home/duckdb_unsigned_extensions/json.duckdb_extension';\")\n\n# use the extension\n{:ok, _} = Duckdbex.query(conn, \"SELECT * FROM read_json_objects('some_data.json');\")\n...\n```\n\nDocumentation generated with [ExDoc](https://github.com/elixir-lang/ex_doc)","ref":"readme.html#custom-build-duckdb-extensions"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\n0.3.8\n- Added transaction managing functions: begin_transaction, commit, rollback, set_auto_commit, is_auto_commit, has_active_transaction\n\n0.3.7\n- DuckDB 1.1.3 bugfix release.\n- Added release(resource) function.\n- Extended DbConfig with new parameters.\n- Now INTERVAL type in Elixir is tuple of size 3 : {months, days, micros} (Here in month 30 days...).\n- Now MAP type in Elixir is list of tuples [{key, value}]. Because MAP is ordered list and 'key' can be any type.","ref":"changelog.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}